======================
 Invenio-App v1.0.0a3
======================

Invenio-App v1.0.0a3 was released on August 5, 2017.

About
-----
WSGI, Celery and CLI applications for Invenio flavours.

What's new
----------

- Initial public release.

Installation
------------

   $ pip install invenio-app==1.0.0a3

Documentation
-------------

   https://invenio-app.readthedocs.io/

Happy hacking and thanks for flying Invenio-App.

| Invenio Development Team
|   Email: info@inveniosoftware.org
|   IRC: #invenio on irc.freenode.net
|   Twitter: https://twitter.com/inveniosoftware
|   GitHub: https://github.com/inveniosoftware/invenio-app
|   URL: http://inveniosoftware.org
